@@ -1,10 +1,10 @@
 package Method::Generate::BuildAll;
 
-use Moo::_strictures;
-use Moo::Object ();
-our @ISA = qw(Moo::Object);
-use Sub::Quote qw(quote_sub quotify);
+use strictures 1;
+use base qw(Moo::Object);
+use Sub::Quote;
 use Moo::_Utils;
+use B 'perlstring';
 
 sub generate_method {
   my ($self, $into) = @_;
@@ -17,7 +17,7 @@ sub generate_method {
 
 sub _handle_subbuild {
   my ($self, $into) = @_;
-  '    if (ref($_[0]) ne '.quotify($into).') {'."\n".
+  '    if (ref($_[0]) ne '.perlstring($into).') {'."\n".
   '      return shift->Moo::Object::BUILDALL(@_)'.";\n".
   '    }'."\n";
 }
@@ -28,9 +28,7 @@ sub buildall_body_for {
     grep *{_getglob($_)}{CODE},
     map "${_}::BUILD",
     reverse @{Moo::_Utils::_get_linear_isa($into)};
-  '    unless (('.$args.')[0]->{__no_BUILD__}) {'."\n"
-  .join('', map qq{      ${me}->${_}(${args});\n}, @builds)
-  ."   }\n";
+  join '', map qq{    ${me}->${_}(${args});\n}, @builds;
 }
 
 1;
